@@ -6,9 +6,7 @@ from typing import Dict, Any, List
 import psutil  #  type: ignore
 from uptime import uptime  # type: ignore
 
-from yaqd_core import Sensor, logging
-
-from .__version__ import __branch__
+from yaqd_core import Sensor
 
 
 def diskio():
@@ -25,14 +23,11 @@ def diskio():
 
 class SystemMonitor(Sensor):
     _kind = "system-monitor"
-    _version = "1.0.0" + f"+{__branch__}" if __branch__ else ""
-    traits: List[str] = []
-    defaults: Dict[str, Any] = {}
 
     def __init__(self, name, config, config_filepath):
         super().__init__(name, config, config_filepath)
-        self.channel_names = ["cpu", "memory", "diskio", "uptime"]
-        self.channel_units = {"cpu": "%", "memory": "%", "diskio": "%", "uptime": "s"}
+        self._channel_names = ["cpu", "memory", "diskio", "uptime"]
+        self._channel_units = {"cpu": "%", "memory": "%", "diskio": "%", "uptime": "s"}
 
     async def _measure(self):
         out = dict()
@@ -40,6 +35,6 @@ class SystemMonitor(Sensor):
         out["memory"] = 100 - dict(psutil.virtual_memory()._asdict())["percent"]
         out["diskio"] = diskio()
         out["uptime"] = uptime()
-        if self.looping:
+        if self._looping:
             await asyncio.sleep(1)
         return out
